==> haskell-hslua-core-2.3.1-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.1
visibility:           public
id:                   hslua-core-2.3.1-2nzTvfsqVknCIzNS5qYfSv
key:                  hslua-core-2.3.1-2nzTvfsqVknCIzNS5qYfSv
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  8fc200cdb30af7d3d43e319a264e6d15
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-GbMiyupp2W8DLzgxAUTzTC:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.1-2nzTvfsqVknCIzNS5qYfSv
depends:
    base-4.17.2.1 bytestring-0.11.5.3 exceptions-0.10.5
    lua-2.3.3-GbMiyupp2W8DLzgxAUTzTC mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-core-2.3.1-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.1
visibility:           public
id:                   hslua-core-2.3.1-KVZAOBtyBRJJfQ9Z1lLe3O
key:                  hslua-core-2.3.1-KVZAOBtyBRJJfQ9Z1lLe3O
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  b7f8607647275417ec685a0cb3f5c90b
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-ELjw8zK7pFtHRKODFiJpGG:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-core-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.1-KVZAOBtyBRJJfQ9Z1lLe3O
depends:
    base-4.17.2.1 bytestring-0.11.5.3 exceptions-0.10.5
    lua-2.3.3-ELjw8zK7pFtHRKODFiJpGG mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
